==> mediawiki_1.43.0.orig.tar.gz: mediawiki-1.43.0/includes/installer/WebInstallerComplete.php <==
<?php
/**
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 * http://www.gnu.org/copyleft/gpl.html
 *
 * @file
 * @ingroup Installer
 */

namespace MediaWiki\Installer;

use HtmlArmor;
use MediaWiki\Message\Message;

class WebInstallerComplete extends WebInstallerPage {

	public function execute() {
		// Pop up a dialog box, to make it difficult for the user to forget
		// to download the file
		$lsUrl = $this->getVar( 'wgServer' ) . $this->parent->getUrl( [ 'localsettings' => 1 ] );
		$this->parent->request->response()->header( "Refresh: 0;url=$lsUrl" );
		$this->startForm();
		$this->parent->disableLinkPopups();
		$location = $this->parent->getLocalSettingsLocation();
		$msg = 'config-install-done';
		if ( $location !== false ) {
			// config-install-done-path
			$msg .= '-path';
		}
		$this->addHTML(
			$this->parent->getInfoBox(
				new HtmlArmor( wfMessage( $msg,
					$lsUrl,
					$this->getVar( 'wgServer' ) .
						$this->getVar( 'wgScriptPath' ) . '/index.php',
					Message::rawParam( $this->parent->makeDownloadLinkHtml() ),
					$location ?: ''
				)->parse() ), 'tick-32.png'
			)
		);
		$this->addHTML( $this->parent->getInfoBox(
			wfMessage( 'config-extension-link' )->plain() ) );

		$this->parent->restoreLinkPopups();
		$this->endForm( false, false );
		return '';
	}

}

==> mediawiki-1.44.0.tar.gz: mediawiki-1.44.0/includes/installer/WebInstallerComplete.php <==
<?php
/**
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 * http://www.gnu.org/copyleft/gpl.html
 *
 * @file
 * @ingroup Installer
 */

namespace MediaWiki\Installer;

class WebInstallerComplete extends WebInstallerPage {

	public function execute() {
		// Pop up a dialog box, to make it difficult for the user to forget
		// to download the file
		$lsPath = $this->parent->getUrl( [ 'localsettings' => 1 ] );
		$lsUrl = $this->parent->getDefaultServer() . $lsPath;
		$this->parent->request->response()->header( "Refresh: 0;url=$lsPath" );
		$this->startForm();
		$this->parent->disableLinkPopups();
		$location = $this->parent->getLocalSettingsLocation();
		$msg = 'config-install-done';
		if ( $location !== false ) {
			$msg = 'config-install-done-path';
		}
		$this->parent->showSuccess( $msg,
			$lsUrl,
			$this->getVar( 'wgServer' ) .
				$this->getVar( 'wgScriptPath' ) . '/index.php',
			"[$lsUrl " . wfMessage( 'config-download-localsettings' )->plain() . ']',
			$location ?: ''
		);
		$this->addHTML( $this->parent->getInfoBox(
			wfMessage( 'config-extension-link' )->plain() ) );

		$this->parent->restoreLinkPopups();
		$this->endForm( false, false );
		return '';
	}

}
